@@ -61,18 +61,6 @@ sub effective_height {
     $obj->height - $obj->border_height;
 }
 
-sub rpn_calc {
-    use Math::RPN;
-    state $re = qr/(?:\d*\.)?\d+|[_a-z]+|--|\+\+|[<>!]=|\S/i;
-    my @terms = map { /$re/g } @_;
-    my @ans = do { local $_; rpn @terms };
-    if (@ans == 1 && $ans[0] && $ans[0] !~ /[^\.\d]/) {
-	int $ans[0];
-    } else {
-	return undef;
-    }
-}
-
 sub foldobj {
     my $obj = shift;
     my $width = shift;
